@@ -1,24 +1,3 @@
-/*
- * Copyright (C) 2003 Paul Davis
- * Copyright (C) 2004 Jack O'Quin
- * Copyright (C) 2006-2007 Grame
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
- *
- */
-
 /* This module provides a set of abstract shared memory interfaces
  * with support using both System V and POSIX shared memory
  * implementations.  The code is divided into three sections:
@@ -31,6 +10,25 @@
  * set in the ./configure step.
  */
 
+/*
+ Copyright (C) 2001-2003 Paul Davis
+ 
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU Lesser General Public License as published by
+ the Free Software Foundation; either version 2.1 of the License, or
+ (at your option) any later version.
+ 
+ This program is distributed in the hope that it will be useful,
+ but WITHOUT ANY WARRANTY; without even the implied warranty of
+ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ GNU Lesser General Public License for more details.
+ 
+ You should have received a copy of the GNU Lesser General Public License
+ along with this program; if not, write to the Free Software 
+ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ 
+ */
+
 #include "JackConstants.h"
 
 #ifdef WIN32
@@ -514,7 +512,7 @@ jack_register_server (const char *server_name, int new_registry)
 
  unlock:
 	jack_shm_unlock_registry ();
-	return 0;
+	return res;
 }
 
 /* release server_name registration */
