@@ -37,6 +37,8 @@ int jack_buffer_size;
 
 double resample_mean = 1.0;
 double static_resample_factor = 1.0;
+double resample_lower_limit = 0.25;
+double resample_upper_limit = 4.0;
 
 double *offset_array;
 double *window_array;
@@ -395,8 +397,8 @@ int process (jack_nframes_t nframes, void *arg) {
     output_offset = (float) offset;
 
     // Clamp a bit.
-    if( current_resample_factor < 0.25 ) current_resample_factor = 0.25;
-    if( current_resample_factor > 4 ) current_resample_factor = 4;
+    if( current_resample_factor < resample_lower_limit ) current_resample_factor = resample_lower_limit;
+    if( current_resample_factor > resample_upper_limit ) current_resample_factor = resample_upper_limit;
 
     // Now Calculate how many samples we need.
     rlen = ceil( ((double)nframes) * current_resample_factor )+2;
@@ -666,6 +668,8 @@ int main (int argc, char *argv[]) {
 	sample_rate = jack_sample_rate;
 
     static_resample_factor =  (double) sample_rate / (double) jack_sample_rate;
+    resample_lower_limit = static_resample_factor * 0.25;
+    resample_upper_limit = static_resample_factor * 4.0;
     resample_mean = static_resample_factor;
 
     offset_array = malloc( sizeof(double) * smooth_size );
